
package com.openexchange.admin.soap.reseller.user.reseller.soap;

import javax.xml.bind.annotation.XmlRegistry;


/**
 * This object contains factory methods for each
 * Java content interface and Java element interface
 * generated in the com.openexchange.admin.soap.reseller.user.reseller.soap package.
 * <p>An ObjectFactory allows you to programatically
 * construct new instances of the Java representation
 * for XML content. The Java representation of XML
 * content can consist of schema derived interfaces
 * and classes representing the binding of schema
 * type definitions, element declarations and model
 * groups.  Factory methods for each of these are
 * provided in this class.
 *
 */
@XmlRegistry
public class ObjectFactory {


    /**
     * Create a new ObjectFactory that can be used to create new instances of schema derived classes for package: com.openexchange.admin.soap.reseller.user.reseller.soap
     *
     */
    public ObjectFactory() {
    }

    /**
     * Create an instance of {@link InvalidDataException }
     *
     */
    public InvalidDataException createInvalidDataException() {
        return new InvalidDataException();
    }

    /**
     * Create an instance of {@link ChangeByModuleAccessName }
     *
     */
    public ChangeByModuleAccessName createChangeByModuleAccessName() {
        return new ChangeByModuleAccessName();
    }

    /**
     * Create an instance of {@link Change }
     *
     */
    public Change createChange() {
        return new Change();
    }

    /**
     * Create an instance of {@link NoSuchContextException }
     *
     */
    public NoSuchContextException createNoSuchContextException() {
        return new NoSuchContextException();
    }

    /**
     * Create an instance of {@link ExistsResponse }
     *
     */
    public ExistsResponse createExistsResponse() {
        return new ExistsResponse();
    }

    /**
     * Create an instance of {@link ListAll }
     *
     */
    public ListAll createListAll() {
        return new ListAll();
    }

    /**
     * Create an instance of {@link GetMultipleData }
     *
     */
    public GetMultipleData createGetMultipleData() {
        return new GetMultipleData();
    }

    /**
     * Create an instance of {@link ListByAliasDomain }
     *
     */
    public ListByAliasDomain createListByAliasDomain() {
        return new ListByAliasDomain();
    }

    /**
     * Create an instance of {@link GetModuleAccess }
     *
     */
    public GetModuleAccess createGetModuleAccess() {
        return new GetModuleAccess();
    }

    /**
     * Create an instance of {@link StorageException }
     *
     */
    public StorageException createStorageException() {
        return new StorageException();
    }

    /**
     * Create an instance of {@link GetAccessCombinationName }
     *
     */
    public GetAccessCombinationName createGetAccessCombinationName() {
        return new GetAccessCombinationName();
    }

    /**
     * Create an instance of {@link NoSuchUserException }
     *
     */
    public NoSuchUserException createNoSuchUserException() {
        return new NoSuchUserException();
    }

    /**
     * Create an instance of {@link ListCaseInsensitive }
     *
     */
    public ListCaseInsensitive createListCaseInsensitive() {
        return new ListCaseInsensitive();
    }

    /**
     * Create an instance of {@link GetContextAdminResponse }
     *
     */
    public GetContextAdminResponse createGetContextAdminResponse() {
        return new GetContextAdminResponse();
    }

    /**
     * Create an instance of {@link CreateResponse }
     *
     */
    public CreateResponse createCreateResponse() {
        return new CreateResponse();
    }

    /**
     * Create an instance of {@link Delete }
     *
     */
    public Delete createDelete() {
        return new Delete();
    }

    /**
     * Create an instance of {@link CreateByModuleAccess }
     *
     */
    public CreateByModuleAccess createCreateByModuleAccess() {
        return new CreateByModuleAccess();
    }

    /**
     * Create an instance of {@link CreateByModuleAccessNameResponse }
     *
     */
    public CreateByModuleAccessNameResponse createCreateByModuleAccessNameResponse() {
        return new CreateByModuleAccessNameResponse();
    }

    /**
     * Create an instance of {@link RemoteException }
     *
     */
    public RemoteException createRemoteException() {
        return new RemoteException();
    }

    /**
     * Create an instance of {@link CreateByModuleAccessName }
     *
     */
    public CreateByModuleAccessName createCreateByModuleAccessName() {
        return new CreateByModuleAccessName();
    }

    /**
     * Create an instance of {@link GetMultipleDataResponse }
     *
     */
    public GetMultipleDataResponse createGetMultipleDataResponse() {
        return new GetMultipleDataResponse();
    }

    /**
     * Create an instance of {@link List }
     *
     */
    public List createList() {
        return new List();
    }

    /**
     * Create an instance of {@link Create }
     *
     */
    public Create createCreate() {
        return new Create();
    }

    /**
     * Create an instance of {@link DeleteMultiple }
     *
     */
    public DeleteMultiple createDeleteMultiple() {
        return new DeleteMultiple();
    }

    /**
     * Create an instance of {@link ListAllResponse }
     *
     */
    public ListAllResponse createListAllResponse() {
        return new ListAllResponse();
    }

    /**
     * Create an instance of {@link ListByAliasDomainResponse }
     *
     */
    public ListByAliasDomainResponse createListByAliasDomainResponse() {
        return new ListByAliasDomainResponse();
    }

    /**
     * Create an instance of {@link ChangeByModuleAccess }
     *
     */
    public ChangeByModuleAccess createChangeByModuleAccess() {
        return new ChangeByModuleAccess();
    }

    /**
     * Create an instance of {@link DuplicateExtensionException }
     *
     */
    public DuplicateExtensionException createDuplicateExtensionException() {
        return new DuplicateExtensionException();
    }

    /**
     * Create an instance of {@link GetAccessCombinationNameResponse }
     *
     */
    public GetAccessCombinationNameResponse createGetAccessCombinationNameResponse() {
        return new GetAccessCombinationNameResponse();
    }

    /**
     * Create an instance of {@link InvalidCredentialsException }
     *
     */
    public InvalidCredentialsException createInvalidCredentialsException() {
        return new InvalidCredentialsException();
    }

    /**
     * Create an instance of {@link GetData }
     *
     */
    public GetData createGetData() {
        return new GetData();
    }

    /**
     * Create an instance of {@link GetContextAdmin }
     *
     */
    public GetContextAdmin createGetContextAdmin() {
        return new GetContextAdmin();
    }

    /**
     * Create an instance of {@link ListCaseInsensitiveResponse }
     *
     */
    public ListCaseInsensitiveResponse createListCaseInsensitiveResponse() {
        return new ListCaseInsensitiveResponse();
    }

    /**
     * Create an instance of {@link Exists }
     *
     */
    public Exists createExists() {
        return new Exists();
    }

    /**
     * Create an instance of {@link ListResponse }
     *
     */
    public ListResponse createListResponse() {
        return new ListResponse();
    }

    /**
     * Create an instance of {@link GetModuleAccessResponse }
     *
     */
    public GetModuleAccessResponse createGetModuleAccessResponse() {
        return new GetModuleAccessResponse();
    }

    /**
     * Create an instance of {@link CreateByModuleAccessResponse }
     *
     */
    public CreateByModuleAccessResponse createCreateByModuleAccessResponse() {
        return new CreateByModuleAccessResponse();
    }

    /**
     * Create an instance of {@link DatabaseUpdateException }
     *
     */
    public DatabaseUpdateException createDatabaseUpdateException() {
        return new DatabaseUpdateException();
    }

    /**
     * Create an instance of {@link GetDataResponse }
     *
     */
    public GetDataResponse createGetDataResponse() {
        return new GetDataResponse();
    }

    /**
     * Create an instance of {@link Exception }
     *
     */
    public Exception createException() {
        return new Exception();
    }

}
